<?php
/**
 * Functions hooked to custom hook.
 *
 * @package Drizzle_Business
 */

if ( ! function_exists( 'drizzle_business_skip_to_content' ) ) :

	/**
	 * Add skip to content.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_skip_to_content() {
		?><a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'drizzle-business' ); ?></a><?php
	}
endif;

add_action( 'drizzle_business_action_before', 'drizzle_business_skip_to_content', 15 );

if ( ! function_exists( 'drizzle_business_site_branding' ) ) :

	/**
	 * Site branding.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_site_branding() {
		?>
		<div id="main-header" class="clear">
		<div class="container">
		<div class="site-branding">

			<?php drizzle_business_the_custom_logo(); ?>

			<?php $show_title = drizzle_business_get_option( 'show_title' ); ?>
			<?php $show_tagline = drizzle_business_get_option( 'show_tagline' ); ?>

			<?php if ( true === $show_title || true === $show_tagline ) : ?>
				<div id="site-identity">
					<?php if ( true === $show_title ) : ?>
						<?php if ( is_front_page() && is_home() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php endif; ?>
					<?php endif; ?>

					<?php if ( true === $show_tagline ) : ?>
						<p class="site-description"><?php bloginfo( 'description' ); ?></p>
					<?php endif; ?>
				</div><!-- #site-identity -->
			<?php endif; ?>

		</div><!-- .site-branding -->
		<div id="main-nav" class="clear-fix">
			<nav id="site-navigation" class="main-navigation" role="navigation">
				<div class="wrap-menu-content">
					<?php
					wp_nav_menu(
						array(
						'theme_location' => 'primary',
						'menu_id'        => 'primary-menu',
						'fallback_cb'    => 'drizzle_business_primary_navigation_fallback',
						)
					);
					?>
				</div><!-- .wrap-menu-content -->
			</nav><!-- #site-navigation -->
		</div><!-- #main-nav -->
		</div> <!-- .container -->
		</div> <!-- .main-header -->
	<?php
	}

endif;

add_action( 'drizzle_business_action_header', 'drizzle_business_site_branding' );

if ( ! function_exists( 'drizzle_business_mobile_navigation' ) ) :

	/**
	 * Mobile navigation.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_mobile_navigation() {
		?>
		<a id="mobile-trigger" href="#mob-menu"><i class="fa fa-list-ul" aria-hidden="true"></i></a>
		<div id="mob-menu">
			<?php
			wp_nav_menu( array(
				'theme_location' => 'primary',
				'container'      => '',
				'fallback_cb'    => 'drizzle_business_primary_navigation_fallback',
			) );
			?>
		</div>
		<?php
	}

endif;

add_action( 'drizzle_business_action_before', 'drizzle_business_mobile_navigation', 20 );

if ( ! function_exists( 'drizzle_business_footer_copyright' ) ) :

	/**
	 * Footer copyright.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_footer_copyright() {

		// Check if footer is disabled.
		$footer_status = apply_filters( 'drizzle_business_filter_footer_status', true );
		if ( true !== $footer_status ) {
			return;
		}

		// Copyright content.
		$copyright_text = drizzle_business_get_option( 'copyright_text' );
		$copyright_text = apply_filters( 'drizzle_business_filter_copyright_text', $copyright_text );
	?>

	<?php if ( has_nav_menu( 'footer' ) ) : ?>
		<?php
		$footer_menu_content = wp_nav_menu( array(
			'theme_location' => 'footer',
			'container'      => 'div',
			'container_id'   => 'footer-navigation',
			'depth'          => 1,
			'fallback_cb'    => false,
		) );
		?>
	<?php endif; ?>
	<?php if ( ! empty( $copyright_text ) ) : ?>
		<div class="copyright">
			<?php echo wp_kses_post( $copyright_text ); ?>
		</div>
	<?php endif; ?>
	<div class="site-info">
		<a href="<?php echo esc_url( __( 'https://wordpress.org/', 'drizzle-business' ) ); ?>"><?php printf( esc_html__( 'Powered by %s', 'drizzle-business' ), 'WordPress' ); ?></a>
		<span class="sep"> | </span>
		<?php printf( esc_html__( '%1$s by %2$s', 'drizzle-business' ), 'Drizzle Business', '<a href="http://wpdrizzle.com">WP Drizzle</a>' ); ?>
	</div>
	<?php
	}

endif;

add_action( 'drizzle_business_action_footer', 'drizzle_business_footer_copyright', 10 );

if ( ! function_exists( 'drizzle_business_add_sidebar' ) ) :

	/**
	 * Add sidebar.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_add_sidebar() {

		global $post;

		$global_layout = drizzle_business_get_option( 'global_layout' );
		$global_layout = apply_filters( 'drizzle_business_filter_theme_global_layout', $global_layout );

		// Check if single template.
		if ( $post && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'drizzle_business_settings', true );
			if ( isset( $post_options['post_layout'] ) && ! empty( $post_options['post_layout'] ) ) {
				$global_layout = $post_options['post_layout'];
			}
		}

		// Include primary sidebar.
		if ( 'no-sidebar' !== $global_layout ) {
			get_sidebar();
		}

		// Include secondary sidebar.
		switch ( $global_layout ) {
			case 'three-columns':
				get_sidebar( 'secondary' );
				break;

			default:
				break;
		}

	}

endif;

add_action( 'drizzle_business_action_sidebar', 'drizzle_business_add_sidebar' );

if ( ! function_exists( 'drizzle_business_custom_posts_navigation' ) ) :

	/**
	 * Posts navigation.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_custom_posts_navigation() {

		the_posts_pagination();

	}

endif;

add_action( 'drizzle_business_action_posts_navigation', 'drizzle_business_custom_posts_navigation' );

if ( ! function_exists( 'drizzle_business_add_image_in_single_display' ) ) :

	/**
	 * Add image in single template.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_add_image_in_single_display() {

		if ( has_post_thumbnail() ) {
			$args = array(
				'class' => 'drizzle-business-post-thumb aligncenter',
			);
			the_post_thumbnail( 'large', $args );
		}

	}

endif;

add_action( 'drizzle_business_single_image', 'drizzle_business_add_image_in_single_display' );

if ( ! function_exists( 'drizzle_business_add_custom_header' ) ) :

	/**
	 * Add custom header.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_add_custom_header() {

		if ( ( is_front_page() && ! is_home() ) ) {
			return;
		}
		?>
		<div id="custom-header" style="background-image: url('<?php header_image(); ?>');">
			<div class="container">
				<div class="custom-header-content">
					<?php do_action( 'drizzle_business_action_custom_header_title' ); ?>
				</div><!-- .custom-header-content -->
				<?php do_action( 'drizzle_business_action_breadcrumb' ); ?>
			</div><!-- .container -->
		</div><!-- #custom-header -->
		<?php
	}

endif;

add_action( 'drizzle_business_action_before_content', 'drizzle_business_add_custom_header', 6 );

if ( ! function_exists( 'drizzle_business_add_title_in_custom_header' ) ) :

	/**
	 * Add title in custom header.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_add_title_in_custom_header() {

		echo '<h1 class="custom-header-title">';

		if ( is_home() ) {
			echo esc_html( drizzle_business_get_option( 'blog_page_title' ) );
		} elseif ( is_singular() ) {
			echo single_post_title( '', false );
		} elseif ( is_archive() ) {
			the_archive_title();
		} elseif ( is_search() ) {
			printf( esc_html__( 'Search Results for: %s', 'drizzle-business' ),  get_search_query() );
		} elseif ( is_404() ) {
			esc_html_e( '404 Error', 'drizzle-business' );
		}

		echo '</h1>';

	}

endif;

add_action( 'drizzle_business_action_custom_header_title', 'drizzle_business_add_title_in_custom_header' );

if ( ! function_exists( 'drizzle_business_add_breadcrumb' ) ) :

	/**
	 * Add breadcrumb.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_add_breadcrumb() {

		$breadcrumb_type = drizzle_business_get_option( 'breadcrumb_type' );

		// Bail if breadcrumb is disabled.
		if ( 'disabled' === $breadcrumb_type ) {
			return;
		}

		// Bail if home page.
		if ( is_front_page() || is_home() ) {
			return;
		}

		echo '<div id="breadcrumb">';
		drizzle_business_breadcrumb();
		echo '</div><!-- #breadcrumb -->';
		return;

	}

endif;

add_action( 'drizzle_business_action_breadcrumb', 'drizzle_business_add_breadcrumb' );

if ( ! function_exists( 'drizzle_business_footer_goto_top' ) ) :

	/**
	 * Go to top.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_footer_goto_top() {
		echo '<a href="#page" class="scrollup" id="btn-scrollup"><i class="fa fa-angle-up"></i></a>';
	}

endif;

add_action( 'drizzle_business_action_after', 'drizzle_business_footer_goto_top', 20 );

if ( ! function_exists( 'drizzle_business_add_front_page_widget_area' ) ) :

	/**
	 * Add front page widget area.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_add_front_page_widget_area() {

		if ( is_front_page() && ! is_home() ) {
			if ( is_active_sidebar( 'sidebar-front-page-widget-area' ) ) {
				echo '<div id="sidebar-front-page-widget-area" class="widget-area">';
				dynamic_sidebar( 'sidebar-front-page-widget-area' );
				echo '</div><!-- #sidebar-front-page-widget-area -->';
			} else {
				if ( current_user_can( 'edit_theme_options' ) ) {
					echo '<div id="sidebar-front-page-widget-area" class="widget-area">';
					drizzle_business_message_front_page_widget_area();
					echo '</div><!-- #sidebar-front-page-widget-area -->';
				}
			}
		}

	}
endif;

add_action( 'drizzle_business_action_before_content', 'drizzle_business_add_front_page_widget_area', 7 );

if ( ! function_exists( 'drizzle_business_add_footer_widgets' ) ) :

	/**
	 * Add footer widgets.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_add_footer_widgets() {

		get_template_part( 'template-parts/footer-widgets' );

	}
endif;

add_action( 'drizzle_business_action_before_footer', 'drizzle_business_add_footer_widgets', 5 );

if ( ! function_exists( 'drizzle_business_add_sub_header' ) ) :

	/**
	 * Add sub header.
	 *
	 * @since 1.0.0
	 */
	function drizzle_business_add_sub_header() {
		$contact_email         = drizzle_business_get_option( 'contact_email' );
		$contact_number        = drizzle_business_get_option( 'contact_number' );
		$contact_address       = drizzle_business_get_option( 'contact_address' );
		$show_social_in_header = drizzle_business_get_option( 'show_social_in_header' );
		$show_search_in_header = drizzle_business_get_option( 'show_search_in_header' );

		if ( empty( $contact_number ) && empty( $contact_email ) && empty( $contact_address ) ) {
			$contact_status = false;
		} else {
			$contact_status = true;
		}

		if ( false === $contact_status && false === $show_search_in_header && ( false === drizzle_business_get_option( 'show_social_in_header' ) || false === has_nav_menu( 'social' ) ) ) {
			return;
		}
		?>
		<div id="sub-header" class="clear">
		<div class="container">
			<div class="quick-contact">
				<ul>
					<?php if ( $contact_email ) : ?>
						<li><a href="<?php echo esc_url( 'mailto:' . $contact_email ); ?>"><i class="fa fa-envelope" aria-hidden="true"></i><?php echo esc_html( $contact_email ); ?></a></li>
					<?php endif; ?>
					<?php if ( $contact_number ) : ?>
						<li><a href="<?php echo esc_url( 'tel:' . preg_replace( '/\D+/', '', $contact_number ) ); ?>"><i class="fa fa-phone" aria-hidden="true"></i><?php echo esc_html( $contact_number ); ?></a></li>
					<?php endif; ?>
					<?php if ( $contact_address ) : ?>
						<li><i class="fa fa-map-marker" aria-hidden="true"></i><?php echo esc_html( $contact_address ); ?></li>
					<?php endif; ?>
				</ul>
			</div><!-- .quick-contact -->
			<div class="header-social">
				<?php if ( true === $show_social_in_header && has_nav_menu( 'social' ) ) : ?>
					<?php the_widget( 'Drizzle_Business_Social_Widget' ); ?>
				<?php endif; ?>
				<?php if ( true === $show_search_in_header ) : ?>
					<div class="sub-header-right">
						<?php get_search_form(); ?>
					</div><!-- sub-header-right -->
				<?php endif; ?>
			</div><!-- .header-social -->
			</div> <!-- .container -->
		</div><!-- #sub-header -->
	<?php
	}
endif;

add_action( 'drizzle_business_action_before_header', 'drizzle_business_add_sub_header', 5 );
